@@ -62,13 +62,14 @@ class KegbotEnv(object):
         self._event_hub, self._flow_manager, self._tap_manager, self._backend)
     self._drink_manager = manager.DrinkManager(self._event_hub, self._backend)
     self._thermo_manager = manager.ThermoManager(self._event_hub, self._backend)
-    self._subscription_manager = manager.SubscriptionManager(self._event_hub)
 
     self._AttachListeners()
 
     # Build threads
     self._threads = set()
     self.AddThread(kb_threads.EventHubServiceThread(self, 'eventhub-thread'))
+    self._sync_thread = kb_threads.SyncThread(self, 'sync-thread', self._backend)
+    self.AddThread(self._sync_thread)
     self.AddThread(kb_threads.NetProtocolThread(self, 'net-thread'))
     self.AddThread(kb_threads.HeartbeatThread(self, 'heartbeat-thread'))
     self._watchdog_thread = kb_threads.WatchdogThread(self, 'watchdog-thread')
@@ -76,8 +77,7 @@ class KegbotEnv(object):
 
   def _AllManagers(self):
     return (self._tap_manager, self._flow_manager, self._drink_manager,
-        self._thermo_manager, self._authentication_manager,
-        self._subscription_manager)
+        self._thermo_manager, self._authentication_manager)
 
   def _AttachListeners(self):
     for mgr in self._AllManagers():
@@ -109,6 +109,10 @@ class KegbotEnv(object):
   def GetThreads(self):
     return self._threads
 
+  def SyncNow(self):
+    """Visible for testing."""
+    return self._sync_thread.sync_now()
+
 
 class KegbotCoreApp(app.App):
   def __init__(self, name='core'):
@@ -141,7 +145,5 @@ class KegbotCoreApp(app.App):
     event = kbevent.QuitEvent()
     self._env.GetEventHub().PublishEvent(event)
     time.sleep(0.5)
-    self._logger.info('Stopping any remaining threads')
-    self._StopThreads()
     self._logger.info('Kegbot stopped.')
 
